==> haskell-xdg-desktop-entry-0.1.1.2-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xdg-desktop-entry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xdg-desktop-entry
version:              0.1.1.2
visibility:           public
id:                   xdg-desktop-entry-0.1.1.2-72OrpUrSMvaGPydQnn0Qd8
key:                  xdg-desktop-entry-0.1.1.2-72OrpUrSMvaGPydQnn0Qd8
license:              BSD-3-Clause
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/taffybar/xdg-desktop-entry
synopsis:             Parse files conforming to the xdg desktop entry spec
description:          Parse files conforming to the xdg desktop entry spec.
category:             System
abi:                  56d3004be272e9e2cc0557f75320dcb9
exposed:              True
exposed-modules:      System.Environment.XDG.DesktopEntry
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xdg-desktop-entry
hs-libraries:         HSxdg-desktop-entry-0.1.1.2-72OrpUrSMvaGPydQnn0Qd8
depends:
    base-4.17.2.1 directory-1.3.7.1 either-5.0.2-EBAvHhJY7JL3AYIEIY10dy
    filepath-1.4.2.2 ini-0.4.2-LaeHPSWoPv6APtx1OUv8E4
    multimap-1.2.1-IfPJLlwBCWEIVO8zC2m8uz
    safe-0.3.21-KFRRgAe6GBS580TLl39TRp text-2.0.2 transformers-0.5.6.2
    unix-2.7.3 unordered-containers-0.2.20-GHxywVRZMTgDKQfzKfhJsl

haddock-interfaces:
    /usr/share/doc/haskell-xdg-desktop-entry/html/xdg-desktop-entry.haddock

haddock-html:         /usr/share/doc/haskell-xdg-desktop-entry/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xdg-desktop-entry-0.1.1.2-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xdg-desktop-entry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xdg-desktop-entry
version:              0.1.1.2
visibility:           public
id:                   xdg-desktop-entry-0.1.1.2-F00nxEkXI4LH1qHsyutZ8e
key:                  xdg-desktop-entry-0.1.1.2-F00nxEkXI4LH1qHsyutZ8e
license:              BSD-3-Clause
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/taffybar/xdg-desktop-entry
synopsis:             Parse files conforming to the xdg desktop entry spec
description:          Parse files conforming to the xdg desktop entry spec.
category:             System
abi:                  f753c1131f33cda78c65ba1923585a9a
exposed:              True
exposed-modules:      System.Environment.XDG.DesktopEntry
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xdg-desktop-entry
hs-libraries:         HSxdg-desktop-entry-0.1.1.2-F00nxEkXI4LH1qHsyutZ8e
depends:
    base-4.17.2.1 directory-1.3.7.1 either-5.0.2-6pxn4ZHF0O12s0wetU12Eh
    filepath-1.4.2.2 ini-0.4.2-JTogrqpddkDT4bXocKSKu
    multimap-1.2.1-IfPJLlwBCWEIVO8zC2m8uz
    safe-0.3.21-4RbCGR2deY91o6dlI4zODz text-2.0.2 transformers-0.5.6.2
    unix-2.7.3 unordered-containers-0.2.20-Jl6TkouWI2i1D1jczNV0uv

haddock-interfaces:
    /usr/share/doc/haskell-xdg-desktop-entry/html/xdg-desktop-entry.haddock

haddock-html:         /usr/share/doc/haskell-xdg-desktop-entry/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
